@@ -1,9 +1,7 @@
 package Catmandu::Fix::uuid;
 
-our $VERSION = '0.12_001';
-
 use Catmandu::Sane;
-use Data::UUID::MT;
+use Data::UUID;
 use Moo;
 use Catmandu::Fix::Has;
 
@@ -17,7 +15,7 @@ sub emit {
 
     $fixer->emit_create_path($fixer->var, $path, sub {
         my $var = shift;
-        "${var} = Data::UUID::MT->new(version => 4)->create_string;";
+        "${var} = Data::UUID->new->create_str();";
     });
 }
 
